@@ -1,7 +1,7 @@
 # ============================================================
 #
 # Copyright (C) 2010 by Johannes Wienke <jwienke at techfak dot uni-bielefeld dot de>
-# Copyright (C) 2011, 2012, 2013 Jan Moringen <jmoringe@techfak.uni-bielefeld.de>
+# Copyright (C) 2011-2016 Jan Moringen <jmoringe@techfak.uni-bielefeld.de>
 #
 # This file may be licensed under the terms of the
 # GNU Lesser General Public License Version 3 (the ``LGPL''),
@@ -33,11 +33,13 @@ registering and selecting them.
 """
 
 from numbers import Integral, Real
+from threading import RLock
 import struct
+import abc
+
 from rsb.protocol.collections.EventsByScopeMap_pb2 import EventsByScopeMap
 from rsb.transport.conversion import notificationToEvent, eventToNotification
 from rsb import Scope
-from threading import RLock
 
 
 class Converter(object):
@@ -131,10 +133,7 @@ class ConverterSelectionStrategy(object):
     .. codeauthor:: jmoringe
     """
     def hasConverterForWireSchema(self, wireSchema):
-        if self._getConverterForWireSchema(wireSchema):
-            return True
-        else:
-            return False
+        return bool(self._getConverterForWireSchema(wireSchema))
 
     def getConverterForWireSchema(self, wireSchema):
         converter = self._getConverterForWireSchema(wireSchema)
@@ -143,10 +142,7 @@ class ConverterSelectionStrategy(object):
         raise KeyError(wireSchema)
 
     def hasConverterForDataType(self, dataType):
-        if self._getConverterForDataType(dataType):
-            return True
-        else:
-            return False
+        return bool(self._getConverterForDataType(dataType))
 
     def getConverterForDataType(self, dataType):
         converter = self._getConverterForDataType(dataType)
@@ -154,6 +150,14 @@ class ConverterSelectionStrategy(object):
             return converter
         raise KeyError(dataType)
 
+    @abc.abstractmethod
+    def _getConverterForWireSchema(self, wireSchma):
+        pass
+
+    @abc.abstractmethod
+    def _getConverterForDataType(self, dataType):
+        pass
+
 
 class ConverterMap(ConverterSelectionStrategy):
     """
@@ -518,6 +522,26 @@ class ProtocolBufferConverter(Converter):
         return str(self)
 
 
+class ScopeConverter(Converter):
+    """
+    (De)serializes :obj:`Scope` objects.
+
+    .. codeauthor:: jmoringe
+    """
+
+    def __init__(self):
+        super(ScopeConverter, self).__init__(bytearray, Scope, 'scope')
+
+    def serialize(self, inp):
+        return bytearray(inp.toString().encode(encoding='ascii')), \
+            self.wireSchema
+
+    def deserialize(self, inp, wireSchema):
+        assert wireSchema == self.wireSchema
+
+        return Scope(str(inp))
+
+
 class EventsByScopeMapConverter(Converter):
     """
     A converter for aggregated events ordered by their scope and time for each
@@ -589,3 +613,4 @@ registerGlobalConverter(BytesConverter())
 registerGlobalConverter(StringConverter(wireSchema="utf-8-string",
                                         dataType=str, encoding="utf_8"))
 registerGlobalConverter(ByteArrayConverter())
+registerGlobalConverter(ScopeConverter())
