@@ -22,21 +22,31 @@
 #
 # ============================================================
 
+"""
+Contains an implementation of the future pattern.
+
+.. codeauthor:: jmoringe
+"""
+
 import threading
 
-class FutureError (RuntimeError):
+
+class FutureError(RuntimeError):
     def __init__(self, *args):
         super(FutureError, self).__init__(*args)
 
-class FutureTimeout (FutureError):
+
+class FutureTimeout(FutureError):
     def __init__(self, *args):
         super(FutureTimeout, self).__init__(*args)
 
-class FutureExecutionError (FutureError):
+
+class FutureExecutionError(FutureError):
     def __init__(self, *args):
         super(FutureExecutionError, self).__init__(*args)
 
-class Future (object):
+
+class Future(object):
     """
     Objects of this class represent the results of in-progress
     operations.
@@ -45,37 +55,42 @@ class Future (object):
     operation, waiting for the operation to finish and retrieving the
     result of the operation.
 
-    @todo: Support Python's native future protocol?
-    See U{http://docs.python.org/dev/library/concurrent.futures.html}
+    .. todo::
 
-    @author: jmoringe
+       Support Python's native future protocol?
+
+    .. codeauthor:: jmoringe
+
+    See Also:
+        <http://docs.python.org/dev/library/concurrent.futures.html>_
     """
 
     def __init__(self):
         """
-        Create a new L{Future} object that represents an in-progress
+        Create a new :obj:`Future` object that represents an in-progress
         operation for which a result is not yet available.
         """
-        self.__error     = False
-        self.__result    = None
+        self.__error = False
+        self.__result = None
 
-        self.__lock      = threading.Lock()
-        self.__condition = threading.Condition(lock = self.__lock)
+        self.__lock = threading.Lock()
+        self.__condition = threading.Condition(lock=self.__lock)
 
     def isDone(self):
         """
         Check whether the represented operation is still in progress.
 
-        @return: C{True} is the represented operation finished
-                 successfully or failed.
-        @rtype: bool
+        Returns:
+            bool:
+                ``True`` is the represented operation finished successfully or
+                failed.
         """
         with self.__lock:
-            return not self.__result is None
+            return self.__result is not None
 
     done = property(isDone)
 
-    def get(self, timeout = 0):
+    def get(self, timeout=0):
         """
         Try to obtain and then return the result of the represented
         operation.
@@ -83,39 +98,48 @@ class Future (object):
         If necessary, wait for the operation to complete, and then
         retrieve its result.
 
-        @param timeout: The amount of time in seconds in which the
-                        operation has to complete.
-        @type timeout: float
-        @return: The result of the operation if it did complete
-                 successfully.
-        @raise FutureExecutionException: If the operation represented
-                                         by the Future object failed.
-        @raise FutureTimeoutException: If the result does not become
-                                       available within the amount of
-                                       time specified via B{timeout}.
+        Args:
+            timeout (float, optional):
+                The amount of time in seconds in which the operation has to
+                complete.
+
+        Returns:
+            The result of the operation if it did complete successfully.
+
+        Raises:
+            FutureExecutionException:
+                If the operation represented by the Future object failed.
+            FutureTimeoutException:
+                If the result does not become available within the amount of
+                time specified via ``timeout``.
         """
         with self.__lock:
             while self.__result is None:
                 if timeout <= 0:
                     self.__condition.wait()
                 else:
-                    # TODO(jmoringe): this is probably wrong since there may be spurious wakeups
-                    self.__condition.wait(timeout = timeout)
+                    # TODO(jmoringe): this is probably wrong since there
+                    #                 may be spurious wakeups
+                    self.__condition.wait(timeout=timeout)
                     if self.__result is None:
-                        raise FutureTimeout, 'Timeout while waiting for result; Waited %s seconds.' \
-                            % timeout
+                        raise FutureTimeout(
+                            'Timeout while waiting for result; '
+                            'Waited %s seconds.' % timeout)
 
         if self.__error:
-            raise FutureExecutionError, 'Failed to execute operation: %s' % self.__result
+            raise FutureExecutionError('Failed to execute operation: %s' %
+                                       self.__result)
 
         return self.__result
 
     def set(self, result):
         """
-        Set the result of the L{Future} to B{result} and wake all
+        Set the result of the :obj:`Future` to ``result`` and wake all
         threads waiting for the result.
 
-        @param result: The result of the L{Future} object.
+        Args:
+            result:
+                The result of the :obj:`Future` object.
         """
         with self.__lock:
             self.__result = result
@@ -123,17 +147,17 @@ class Future (object):
 
     def setError(self, message):
         """
-        Mark the operation represented by the L{Future} object as
-        failed, set B{message} as the error message and notify all
+        Mark the operation represented by the :obj:`Future` object as
+        failed, set ``message`` as the error message and notify all
         threads waiting for the result.
 
-        @param message: An error message that explains why/how the
-                        operation failed.
-        @type message: str
+        Args:
+            message (str):
+                An error message that explains why/how the operation failed.
         """
         with self.__lock:
             self.__result = message
-            self.__error  = True
+            self.__error = True
             self.__condition.notify()
 
     def __str__(self):
@@ -149,13 +173,14 @@ class Future (object):
     def __repr__(self):
         return str(self)
 
-class DataFuture (Future):
-    """
-    Instances of this class are like ordinary L{Future}s, the only
-    difference being that the L{get} method returns the payload of an
-    L{Event} object.
 
-    @author: jmoringe
+class DataFuture(Future):
     """
-    def get(self, timeout = 0):
-        return super(DataFuture, self).get(timeout = timeout).data
+    Instances of this class are like ordinary :obj:`Future`s, the only
+    difference being that the :obj:`get` method returns the payload of an
+    :obj:`Event` object.
+
+    .. codeauthor:: jmoringe
+    """
+    def get(self, timeout=0):
+        return super(DataFuture, self).get(timeout=timeout).data
